function [] = timeOfArrival()
%TIMEOFARRIVAL Defines the ARTOA4 edit time of arrival window.

global artoaGui artoaWorkspace;

%% Initialize required variables

windowTitle = [ 'ARTOA4 - Float ' num2str(artoaWorkspace.float.floatname) ' - Time of arrival' ];


%% Initialize time of arrival gui

artoaGui.figures.editTimeOfArrival = figure( ...
    'Name', windowTitle, ...
    'NumberTitle', 'off' ...
);
addToolbarExplorationButtons(artoaGui.figures.editTimeOfArrival);

artoaGui.editTimeOfArrival = struct();

set( ...
    artoaGui.figures.editTimeOfArrival, ...
    'CloseRequestFcn', ...
    'artoa.controller.edit.timeOfArrival.close();', ...
    'Units', 'normalized' ...
);

%% Generate Plot

artoa.controller.edit.timeOfArrival.plot();

%% Generate Controls

left = .85;
width = .14;

%% Selection frame
artoaGui.editTimeOfArrival.frameControlsSelect = uipanel( ...
    'Title', 'Select', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .7 width .2] ...
);

artoaGui.editTimeOfArrival.buttonPickPolygon = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSelect, ...
    'String', 'Polygon', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .7 .69 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.pickPolygon();' ...
);

artoaGui.editTimeOfArrival.buttonPickPoint = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSelect, ...
    'String', 'Point', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .4 .69 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.pickPoint();' ...
);

artoaGui.editTimeOfArrival.buttonDropSelection = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSelect, ...
    'String', 'Drop', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .1 .69 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.dropSelection();' ...
);

%% Shift frame
artoaGui.editTimeOfArrival.frameControlsShift = uipanel( ...
    'Title', 'Shift', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .45 width .2] ...
);

artoaGui.editTimeOfArrival.buttonShiftApply = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsShift, ...
    'String', 'Apply', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .7 .69 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.shiftToa();' ...
);

artoaGui.editTimeOfArrival.buttonShiftResetSelection = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsShift, ...
    'String', 'Reset', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .4 .69 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.resetShiftToa();' ...
);

%% Sound source frame

artoaGui.editTimeOfArrival.frameControlsSoundSource = uipanel( ...
    'Title', 'Soundsource', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .1 width .3] ...
);

artoaGui.editTimeOfArrival.buttonApply = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSoundSource, ...
    'String', 'Apply', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .8 .69 .15], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.applySoundSourceToSelectedPoints();' ...
);

artoaGui.editTimeOfArrival.buttonApplyAllVisible = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSoundSource, ...
    'String', 'Apply All Visible', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .6 .69 .15], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.applySoundSourceToAllVisible();' ...
);

artoaGui.editTimeOfArrival.buttonDelete = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSoundSource, ...
    'String', 'Withdraw', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .4 .69 .15], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.removeSoundSourceFromSelectedPoints();' ...
);

artoaGui.editTimeOfArrival.buttonWithdrawAllVisible = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsSoundSource, ...
    'String', 'Withdraw All Visible', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.156 .2 .69 .15], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.withdrawSoundSourceToAllVisible();' ...
);

%% Duplicate applied TOA table

artoaGui.editTimeOfArrival.frameDuplicateAppliedToa = uipanel( ...
    'Title', 'Duplicates', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [.01 .25 width .15] ...
);

columns = { ...
    'Soundsource', 'Date', 'TOAs' ...
};
artoaGui.editTimeOfArrival.tableDuplicateAppliedToa = uitable( ...
    artoaGui.editTimeOfArrival.frameDuplicateAppliedToa, ...
    'Units', 'normalized', ...
    'Position', [.1, .1, .8, .8], ...
    'Data', cell(1, length(columns)), ...
    'ColumnName', columns, ...
    'ColumnEditable', false, ...
    'CellSelectionCallback', @artoa.controller.edit.timeOfArrival.tableDuplicateToaSelection,...
    'CellEditCallback', '', ...
    'ColumnWidth', {60, 120, 120} ...
);
clear columns;

%% Sound source color legend frame

artoa.controller.edit.timeOfArrival.createSoundsourceColorsPanel();

%% TOA Histogram

artoaGui.editTimeOfArrival.frameToaHistogram = uipanel( ...
    'Title', 'TOA histogram', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [.01 .45 width .15] ...
);

%% Update histogram
artoa.controller.edit.timeOfArrival.plotToaHistogram()


%% Colormap slider

artoaGui.editTimeOfArrival.frameControlsColormapSlider = uipanel( ...
    'Title', 'Adjust colormap boundaries', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [.01 .1 width .1] ...
);

artoaGui.editTimeOfArrival.textUpperBoundary = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsColormapSlider, ...
    'String', 'Upper', ...
    'Style', 'text', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.1 .6 .2 .2] ...
);

artoaGui.editTimeOfArrival.sliderUpperBoundary = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsColormapSlider, ...
    'Style', 'slider', ...
    'Units', 'normalized', ...
    'Max', 255, ...
    'Min', 0, ...
    'Value', 255, ...
    'Position', [.4 .6 .3 .2], ...
    'Callback', 'artoa.controller.edit.timeOfArrival.updateUpperColormapBoundary();'...
);

artoaGui.editTimeOfArrival.inputUpperBoundary = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsColormapSlider, ...
    'String', '255', ...
    'Style', 'edit', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.8 .6 .1 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.updateUpperColormapBoundary(true);' ...
);

artoaGui.editTimeOfArrival.textLowerBoundary = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsColormapSlider, ...
    'String', 'Lower', ...
    'Style', 'text', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.1 .2 .2 .2] ...
);

artoaGui.editTimeOfArrival.sliderLowerBoundary = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsColormapSlider, ...
    'Style', 'slider', ...
    'Units', 'normalized', ...
    'Max', 255, ...
    'Min', 0, ...
    'Value', 0, ...
    'Position', [.4 .2 .3 .2], ...
    'Callback', 'artoa.controller.edit.timeOfArrival.updateLowerColormapBoundary();'...
);

artoaGui.editTimeOfArrival.inputLowerBoundary = uicontrol( ...
    'Parent', artoaGui.editTimeOfArrival.frameControlsColormapSlider, ...
    'String', '0', ...
    'Style', 'edit', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.8 .2 .1 .2], ...
    'CallBack', 'artoa.controller.edit.timeOfArrival.updateLowerColormapBoundary(true);' ...
);

%% Enable zoom
zoom on;

end

